import React from 'react';

import { AutofillRetrieveResponse } from '@mapbox/search-js-core';
import {
  AddressAutofill,
  useConfirmAddress,
  AddressMinimap,
  config
} from '../src';

// Autofilled by ESBuild.
const ACCESS_TOKEN = MAPBOX_ACCESS_TOKEN;
config.accessToken = ACCESS_TOKEN;

export function Autofill(): React.ReactElement {
  const [value, setValue] = React.useState('');
  const [text, setText] = React.useState('');
  const [showMinimap, setShowMinimap] = React.useState(false);
  const [feature, setFeature] =
    React.useState<GeoJSON.Feature<GeoJSON.Point>>();

  const { formRef, showConfirm } = useConfirmAddress({
    footer: 'My custom footer'
  });

  const handleRetrieve = React.useCallback(
    (res: AutofillRetrieveResponse) => {
      console.log('retrieve', res);
      const feature = res.features[0];
      setText(feature.properties.full_address);
      setFeature(feature);
      setShowMinimap(true);
    },
    [setText, setFeature, setShowMinimap]
  );

  const handleSaveMarkerLocation = React.useCallback(
    (coordinate: [number, number]) => {
      if (coordinate.toString() !== feature.geometry.coordinates.toString()) {
        console.log(`Marker updated to ${JSON.stringify(coordinate)}.`);
      }
    },
    [feature]
  );

  const handleSubmit = React.useCallback(async () => {
    const result = await showConfirm();
    console.log(result);
  }, [showConfirm]);

  const inputStyle = {
    border: '1px solid black',
    marginTop: 6,
    borderRadius: 6
  };

  return (
    <div>
      <form
        ref={formRef}
        style={{ display: 'flex', flexDirection: 'column', marginTop: 30 }}
      >
        <AddressAutofill
          accessToken={ACCESS_TOKEN}
          browserAutofillEnabled={true}
          popoverOptions={{ flip: true, offset: 0 }}
          onChange={(v) => console.log('change', v)}
          onSuggest={(res) => console.log('suggest', res)}
          onSuggestError={(err) => console.log('error', err)}
          onRetrieve={handleRetrieve}
          confirmOnBrowserAutofill={{ minimap: true }}
        >
          <input
            autoComplete="shipping address-line1"
            value={value}
            onChange={(e) => setValue(e.target.value)}
            style={inputStyle}
            placeholder="Address"
          />
        </AddressAutofill>
        <input
          autoComplete="shipping address-line2"
          placeholder="Apt / Bldg / Unit"
          style={inputStyle}
        />
        <input
          autoComplete="shipping address-level2"
          placeholder="City"
          style={inputStyle}
        />
        <input
          autoComplete="shipping address-level1"
          placeholder="State"
          style={inputStyle}
        />
        <input
          autoComplete="shipping postal-code"
          placeholder="Postcode"
          style={inputStyle}
        />
        <p>{text}</p>
      </form>
      <button onClick={handleSubmit}>Submit</button>
      <div style={{ height: 400, width: 800 }}>
        <AddressMinimap
          canAdjustMarker={true}
          satelliteToggle={true}
          feature={feature}
          show={showMinimap}
          onSaveMarkerLocation={handleSaveMarkerLocation}
          footer={'My custom minimap footer'}
          adjustBtnText="Stift anpassen"
          cancelBtnText="Abbrechen"
          saveBtnText="Sparen"
        />
      </div>
    </div>
  );
}
